/**
 *
 * $Id: DumpLayout.h,v 1.4 2000/10/21 09:51:59 amai Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 * Copyright (C) 1995-2000 LessTif Development Team
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

/* Exports from DumpLayout.c */

#ifndef _TEST_DUMPLAYOUT_H
#define _TEST_DUMPLAYOUT_H

void PrintDetails(Widget W, XtWidgetGeometry *Expected);

void PrintDetails2(Widget W, XtWidgetGeometry *Expected);

#endif /* _TEST_DUMPLAYOUT_H */
